.. systest documentation master file, created by
   sphinx-quickstart on Sat Apr 25 11:54:09 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. toctree::
   :maxdepth: 2

systest - System test framework.
================================

.. include:: ../README.rst

Classes
=======

.. autoclass:: systest.TestCase
   :members:
   :member-order: bysource

.. autoclass:: systest.Sequencer
   :members:

.. autofunction:: systest.configure_logging
